@@ -1,5 +1,5 @@
 from xml.etree.ElementTree import SubElement
-from elifecrossref import dates, journal
+from elifecrossref import dates, journal, title
 
 
 def set_pending_publication(parent, poa_article, crossref_config):
@@ -11,6 +11,8 @@ def set_pending_publication(parent, poa_article, crossref_config):
 
     journal.set_issn_tag(publication_tag, poa_article)
 
+    title.set_titles(pending_publication_tag, poa_article.title, crossref_config)
+
     set_acceptance_date(pending_publication_tag, poa_article.get_date("accepted"))
 
     doi_tag = SubElement(pending_publication_tag, "doi")
